@@ -10,9 +10,15 @@ mkdir "$DIST"/.cargo
 # cargo-vendor-filterer can be found at https://github.com/coreos/cargo-vendor-filterer
 # It is also part of the Rust SDK extension.
 cargo vendor-filterer --all-features --platform=x86_64-unknown-linux-gnu --platform=aarch64-unknown-linux-gnu > "$DIST"/.cargo/config.toml
-rm -f vendor/gettext-sys/gettext-*.tar.*
+set -- vendor/gettext-sys/gettext-*.tar.*
+TARBALL_PATH=$1
+TARBALL_NAME=$(basename "$TARBALL_PATH")
+rm -f "$TARBALL_PATH"
 # remove the tarball from checksums
-echo $(jq -c 'del(.files["gettext-0.22.5.tar.xz"])' vendor/gettext-sys/.cargo-checksum.json) > vendor/gettext-sys/.cargo-checksum.json
+cargo_checksum='vendor/gettext-sys/.cargo-checksum.json'
+tmp_f=$(mktemp --tmpdir='vendor/gettext-sys' -t)
+jq -c "del(.files[\"$TARBALL_NAME\"])" "$cargo_checksum" > "$tmp_f"
+mv -f "$tmp_f" "$cargo_checksum"
 # Don't combine the previous and this line with a pipe because we can't catch
 # errors with "set -o pipefail"
 sed -i 's/^directory = ".*"/directory = "vendor"/g' "$DIST/.cargo/config.toml"
