@@ -1,17 +1,14 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
+use std::os::unix::io::OwnedFd;
+
 use adw::prelude::*;
 use adw::subclass::prelude::*;
+use anyhow::Context;
+use ashpd::desktop::camera;
 use gettextrs::gettext;
 use gtk::CompositeTemplate;
 use gtk::{gio, glib};
 
-#[cfg(feature = "portal")]
-use anyhow::Context;
-#[cfg(feature = "portal")]
-use ashpd::desktop::camera;
-#[cfg(feature = "portal")]
-use std::os::unix::io::OwnedFd;
-
 use super::CameraControls;
 use crate::enums::ControlsLayout;
 use crate::{config, utils};
@@ -38,7 +35,7 @@ mod imp {
         pub recording_duration: Cell<u32>,
         pub recording_source: RefCell<Option<glib::source::SourceId>>,
 
-        #[property(get, set = Self::set_capture_mode, explicit_notify, builder(Default::default()))]
+        #[property(get, set = Self::set_capture_mode, explicit_notify, default)]
         capture_mode: Cell<crate::CaptureMode>,
 
         #[template_child]
@@ -248,10 +245,10 @@ mod imp {
 
             self.camera_controls.set_selection(self.selection.clone());
             self.camera_controls.connect_camera_switched(glib::clone!(
-                #[weak(rename_to = obj)]
-                self,
+                #[weak]
+                obj,
                 move |_: &CameraControls| {
-                    obj.obj().camera_switched();
+                    obj.camera_switched();
                 }
             ));
 
@@ -276,6 +273,24 @@ mod imp {
                 .bind("capture-mode", &*obj, "capture-mode")
                 .build();
 
+            let format = if aperture::is_h264_encoding_supported() {
+                log::debug!("Found openh264enc feature, using the h264/mp4 profile");
+                aperture::VideoFormat::H264Mp4
+            } else {
+                log::debug!("Did not find openh264enc feature, using the vp8/webm profile");
+                aperture::VideoFormat::Vp8Webm
+            };
+            self.viewfinder.set_video_format(format);
+
+            self.settings()
+                .bind(
+                    "enable-hardware-encoding",
+                    &*self.viewfinder,
+                    "enable-hw-encoding",
+                )
+                .get_only()
+                .build();
+
             obj.connect_current_breakpoint_notify(glib::clone!(
                 #[weak(rename_to = obj)]
                 self,
@@ -300,7 +315,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct Camera(ObjectSubclass<imp::Camera>)
-        @extends gtk::Widget, adw::BreakpointBin;
+        @extends gtk::Widget, adw::BreakpointBin,
+        @implements gtk::ConstraintTarget, gtk::Buildable, gtk::Accessible;
 }
 
 impl Default for Camera {
@@ -314,7 +330,6 @@ impl Camera {
         Self::default()
     }
 
-    #[cfg(feature = "portal")]
     fn on_portal_not_allowed(&self) {
         // We don't start the device provider if we are not
         // allowed to use cameras.
@@ -331,14 +346,6 @@ impl Camera {
             #[strong]
             provider,
             async move {
-                #[cfg(feature = "portal")]
-                if let Err(err) = ashpd::register_host_app(config::APP_ID.try_into().unwrap()).await
-                {
-                    log::error!(
-                        "Failed to run org.freedesktop.host.portal.Registry.Register: {err}"
-                    );
-                }
-                #[cfg(feature = "portal")]
                 match stream().await {
                     Ok(fd) => {
                         if let Err(err) = provider.set_fd(fd) {
@@ -383,11 +390,13 @@ impl Camera {
         ));
     }
 
-    pub async fn start_recording(&self, format: crate::VideoFormat) -> anyhow::Result<()> {
+    pub async fn start_recording(&self) -> anyhow::Result<()> {
+        let imp = self.imp();
+        let format = imp.viewfinder.video_format();
         let filename = utils::video_file_name(format);
         let path = utils::videos_dir()?.join(filename);
 
-        self.imp().viewfinder.start_recording(path)?;
+        imp.viewfinder.start_recording(path)?;
 
         Ok(())
     }
@@ -647,7 +656,6 @@ impl Camera {
     }
 }
 
-#[cfg(feature = "portal")]
 async fn stream() -> anyhow::Result<OwnedFd> {
     let proxy = camera::Camera::new().await?;
     proxy
