@@ -49,14 +49,14 @@ mod imp {
             klass.set_css_name("gallery");
 
             // Shows an older picture (scrolls to the right)
-            klass.install_action("gallery.next", None, move |widget, _, _| {
+            klass.install_action("gallery.next", None, |widget, _, _| {
                 widget.next();
             });
             // Shows a newer picture (scrolls to the left)
-            klass.install_action("gallery.previous", None, move |widget, _, _| {
+            klass.install_action("gallery.previous", None, |widget, _, _| {
                 widget.previous();
             });
-            klass.install_action_async("gallery.open", None, |widget, _, _| async move {
+            klass.install_action_async("gallery.open", None, async |widget, _, _| {
                 if let Err(err) = widget.open_with_system().await {
                     log::error!("Could not open with system handler: {err}");
                 }
@@ -66,11 +66,38 @@ mod imp {
                     log::error!("Could not copy gallery item: {err}");
                 }
             });
-            klass.install_action_async("gallery.delete", None, |widget, _, _| async move {
+            klass.install_action_async("gallery.delete", None, async |widget, _, _| {
                 if let Err(err) = widget.delete().await {
                     log::error!("Could not delete gallery item: {err}");
                 }
             });
+
+            klass.add_binding_action(
+                gdk::Key::Right,
+                gdk::ModifierType::NO_MODIFIER_MASK,
+                "gallery.next",
+            );
+            klass.add_binding_action(
+                gdk::Key::KP_Right,
+                gdk::ModifierType::NO_MODIFIER_MASK,
+                "gallery.next",
+            );
+            klass.add_binding_action(
+                gdk::Key::Left,
+                gdk::ModifierType::NO_MODIFIER_MASK,
+                "gallery.previous",
+            );
+            klass.add_binding_action(
+                gdk::Key::KP_Left,
+                gdk::ModifierType::NO_MODIFIER_MASK,
+                "gallery.previous",
+            );
+
+            klass.add_binding_action(
+                gdk::Key::Escape,
+                gdk::ModifierType::NO_MODIFIER_MASK,
+                "win.toggle-gallery",
+            );
         }
 
         fn instance_init(obj: &glib::subclass::InitializingObject<Self>) {
@@ -167,7 +194,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct Gallery(ObjectSubclass<imp::Gallery>)
-        @extends gtk::Widget, adw::BreakpointBin;
+        @extends gtk::Widget, adw::BreakpointBin,
+        @implements gtk::ConstraintTarget, gtk::Buildable, gtk::Accessible;
 }
 
 impl Default for Gallery {
