@@ -4,10 +4,10 @@ use gettextrs::gettext;
 use gtk::subclass::prelude::*;
 use gtk::{gio, glib};
 
-use crate::config::{APP_ID, IS_DEVEL};
-use crate::utils;
 use crate::Application;
 use crate::CaptureMode;
+use crate::config::{APP_ID, IS_DEVEL, VERSION};
+use crate::utils;
 
 mod imp {
     use std::cell::{Cell, RefCell};
@@ -69,6 +69,7 @@ mod imp {
                 self.camera.stop_recording();
             }
 
+            log::debug!("Camera page hidden: stopping stream");
             self.camera.stop_stream();
 
             match obj.capture_mode() {
@@ -82,6 +83,7 @@ mod imp {
 
         #[template_callback]
         fn on_camera_page_showing(&self) {
+            log::debug!("Camera page showing: starting stream");
             self.camera.start_stream();
             self.obj().set_shutter_enabled(true);
         }
@@ -97,7 +99,7 @@ mod imp {
             klass.bind_template();
             klass.bind_template_callbacks();
 
-            klass.install_action_async("win.take-picture", None, |window, _, _| async move {
+            klass.install_action_async("win.take-picture", None, async |window, _, _| {
                 if let Err(err) = window.on_take_picture().await {
                     match window.capture_mode() {
                         CaptureMode::Picture => {
@@ -112,10 +114,10 @@ mod imp {
                     }
                 };
             });
-            klass.install_action("win.about", None, move |window, _, _| {
+            klass.install_action("win.about", None, |window, _, _| {
                 window.show_about_dialog();
             });
-            klass.install_action("win.toggle-gallery", None, move |window, _, _| {
+            klass.install_action("win.toggle-gallery", None, |window, _, _| {
                 let imp = window.imp();
 
                 if imp
@@ -129,12 +131,12 @@ mod imp {
                     imp.navigation_view.pop();
                 }
             });
-            klass.install_action("win.toggle-guidelines", None, move |window, _, _| {
+            klass.install_action("win.toggle-guidelines", None, |window, _, _| {
                 let imp = window.imp();
 
                 imp.camera.toggle_guidelines();
             });
-            klass.install_action("win.preferences", None, move |window, _, _| {
+            klass.install_action("win.preferences", None, |window, _, _| {
                 window.show_preferences_window();
             });
         }
@@ -176,6 +178,17 @@ mod imp {
                 }
             ));
 
+            obj.connect_suspended_notify(|window| {
+                let imp = window.imp();
+                if window.is_suspended() && !imp.camera.is_recording_active() {
+                    log::debug!("Window suspended: stopping stream");
+                    imp.camera.stop_stream();
+                } else {
+                    log::debug!("Window un-suspended: starting stream");
+                    imp.camera.start_stream();
+                }
+            });
+
             // Load latest window state
             obj.load_window_size();
             obj.setup_gactions();
@@ -230,7 +243,7 @@ mod imp {
 glib::wrapper! {
     pub struct Window(ObjectSubclass<imp::Window>)
         @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow, adw::ApplicationWindow,
-        @implements gio::ActionMap, gio::ActionGroup, gtk::Root;
+        @implements gio::ActionMap, gio::ActionGroup, gtk::ConstraintTarget, gtk::Accessible, gtk::Buildable, gtk::ShortcutManager, gtk::Native, gtk::Root;
 }
 
 impl Window {
@@ -296,13 +309,17 @@ impl Window {
     fn show_about_dialog(&self) {
         let dialog = adw::AboutDialog::from_appdata(
             &format!("/org/gnome/Snapshot/{APP_ID}.metainfo.xml"),
-            None,
+            VERSION.split('-').next(),
         );
         dialog.set_translator_credits(&gettext("translator-credits"));
         dialog.set_developers(&["Maximiliano Sandoval", "Jamie Murphy <jmurphy@gnome.org>"]);
         dialog.set_designers(&["Tobias Bernard"]);
         dialog.set_debug_info(&utils::debug_info());
 
+        if IS_DEVEL {
+            dialog.set_version(VERSION);
+        }
+
         dialog.present(Some(self));
     }
 
@@ -380,8 +397,7 @@ impl Window {
                 imp.camera.stop_recording();
                 self.set_shutter_enabled(true);
             } else {
-                let format = imp.settings.enum_("video-format").into();
-                imp.camera.start_recording(format).await?;
+                imp.camera.start_recording().await?;
             }
         } else {
             let format = imp.settings.enum_("picture-format").into();
@@ -427,7 +443,8 @@ impl Window {
         if self.visible_dialog().is_some() {
             return;
         }
-        let preferences = crate::PreferencesWindow::default();
+        let is_recording = self.imp().camera.is_recording_active();
+        let preferences = crate::PreferencesWindow::new(is_recording);
         preferences.present(Some(self));
     }
 
